@@ -2,7 +2,7 @@ package App::RecordStream::Bio;
 
 use strict;
 use 5.010;
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 # For informational purposes only in the fatpacked file, so it's OK to fail.
 # For now, classes are still under the App::RecordStream::Operation namespace
@@ -28,14 +28,18 @@ App::RecordStream::Bio - A collection of record-handling tools related to biolog
 
     # Turn a FASTA into a CSV after filtering for sequence names containing the
     # words POL or GAG.
-    recs-fromfasta --oneline < seqs.fasta           \
-        | recs-grep '{{id}} =~ /\b(POL|GAG)\b/i'    \
-        | recs-tocsv -k id,sequence
+    recs fromfasta --oneline < seqs.fasta           \
+        | recs grep '{{id}} =~ /\b(POL|GAG)\b/i'    \
+        | recs tocsv -k id,sequence
     
     # Filter gaps from sequences
-    recs-fromfasta seqs.fasta \
-        | recs-xform '{{seq}} =~ s/-//g' \
-        | recs-tofasta > seqs-nogaps.fasta
+    recs fromfasta seqs.fasta \
+        | recs xform '{{seq}} =~ s/-//g' \
+        | recs tofasta > seqs-nogaps.fasta
+
+    # Calculate average mapping quality from SAM reads
+    recs fromsam input.sam \
+        | recs collate -a avg,mapq
 
 =head1 DESCRIPTION
 
@@ -49,6 +53,8 @@ them via their command line wrappers within a larger record stream pipeline.
 
 L<recs-fromfasta>
 
+L<recs-fromsam>
+
 L<recs-tofasta>
 
 =head1 INSTALLATION
@@ -71,6 +77,7 @@ Congrats, you should now be able to run:
 
   ./recs fromfasta --help
   ./recs tofasta --help
+  ./recs fromsam --help
 
 recs version 4.0.14 or newer is required to support site loading from
 F<~/.recs/site>.
